@@ -35,7 +35,8 @@ class FirebaseClient:
         data = {'to': to, 'data': data}
         if ttl:
             data.update({'time_to_live': ttl})
-        return requests.post(url=self._http_google_message_api, data=data)
+        return requests.post(url=self._http_google_message_api,
+                             headers=self.headers, data=data)
 
     def create_device_group(self, group_name, device_tokens):
         if not self.sender_id:
